Struct evm_disassembler::types::Operation
source · pub struct Operation {
pub opcode: Opcode,
pub input: Vec<u8>,
pub offset: u32,
}Expand description
A decoded operation
An operation is represented by the combination of an opcode, the offset in the bytecode and any additional bytes that are part of the operation (only for PUSH operations).
Fields
opcode: OpcodeThe opcode
input: Vec<u8>Additional bytes that are part of the Operation (only for PUSH)
offset: u32The offset in the bytecode
Implementations